A ref for storing the combined configuration properties.
A ref for storing the combined configuration properties.
A ref for storing the props passed in on the command-line.
A ref for storing the props passed in on the command-line.
A ref containing the default values for the config.
A ref containing the default values for the config.
A ref containing a set of keys to filter from configs before printing them.
A ref containing a set of keys to filter from configs before printing them.
(load-properties cfg-path)Loads a properties file into a map, turning the keys into keywords.
Loads a properties file into a map, turning the keys into keywords.
A ref containing a map of bouncer validators for the config file.
A ref containing a map of bouncer validators for the config file.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |